@@ -2929,3 +2929,74 @@ to_ts!(
     }
     "
 );
+
+to_ts!(
+    ts_local_types_4_1,
+    "
+    function f1() {
+        // Type parameters are in scope in parameters and return types
+        function f<T>(x: T): T {
+            return undefined;
+        }
+    }
+    
+    function f2() {
+        // Local types are not in scope in parameters and return types
+        function f(x: T): T {
+            interface T { }
+            return undefined;
+        }
+    }
+    
+    function f3() {
+        // Type parameters and top-level local types are in same declaration space
+        function f<T>() {
+            interface T { }
+            return undefined;
+        }
+    }
+    ",
+    "
+    function f1() {
+        function f__2<T__3>(x__3: T__3): T__3 {
+            return undefined;
+        }
+    }
+    function f2() {
+        function f__4(x__5: T): T {
+            interface T__5 {
+            }
+            return undefined;
+        }
+    }
+    function f3() {
+        function f__6<T__7>() {
+            interface T__7 {
+            }
+            return undefined;
+        }
+    }
+    "
+);
+
+to_ts!(
+    ts_local_types_4_2,
+    "
+    function f2() {
+        // Local types are not in scope in parameters and return types
+        function f(x: T): T {
+            interface T { }
+            return undefined;
+        }
+    }
+    ",
+    "
+    function f2() {
+        function f__2(x__3: T): T {
+            interface T__3 {
+            }
+            return undefined;
+        }
+    }
+    "
+);
